{
const TOOLS_RUNNER_URL = "https://functions.yandexcloud.net/d4esian9gs7m7m80qk1q";
const SHOWDOWN_URL = "https://cdnjs.cloudflare.com/ajax/libs/showdown/2.1.0/showdown.min.js";
const TOOL_ID = "fc7bd1a3-18c2-4eb4-bfdb-d2291153ec78";
const BLOCK_ID = "#rec866794222";

function insertSlideAfter(template_slide, slides_count, slide_index, image) {
  const slide_index_prev = (slide_index + slides_count - 1) % slides_count;
  const slide = template_slide.clone();
  slide.attr("data-slide-index", slide_index);
  slide.find("meta").attr("content", image);
  const zoomable = slide.find('.t-slds__imgwrapper[data-zoomable="yes"]');
  zoomable.attr("bgimgfield", "gi_img__" + slide_index_prev);
  zoomable.attr("data-zoom-target", slide_index_prev);
  zoomable.attr("data-img-zoom-url", image);
  const bgimg = slide.find(".t-slds__imgwrapper .t-bgimg");
  bgimg.attr("data-original", image);
  bgimg.css("background-image", "url('" + image + "')");
  slide.insertAfter(template_slide);
  return slide;
}

function insertThumbAfter(template_thumb, thumb_index, image) {
  const thumb = template_thumb.clone();
  thumb.attr("data-slide-bullet-for", thumb_index);
  const bgimg = thumb.find(".t-bgimg");
  bgimg.attr("data-original", image);
  bgimg.css("background-image", "url('" + image + "')");
  thumb.insertAfter(template_thumb);
  return thumb;
}

function insertBulletAfter(template_bullet, bullet_index) {
  const bullet = template_bullet.clone();
  bullet.attr("data-slide-bullet-for", bullet_index);
  bullet.insertAfter(template_bullet);
  return bullet;
}

$(document).ready(function () {
  const tool_id = TOOL_ID;
  const block_id = BLOCK_ID.substring(4);
  const block = $(BLOCK_ID).removeClass("r_hidden");
  block.find("script").remove();

  block.wrap(`<div id="rec${block_id}" class="r"></div>`).remove();
  block.removeClass("r");
  const container = $(`#rec${block_id}`);

  const project_id = $("#allrecords").attr("data-tilda-project-id");
  const profile = JSON.parse(
    localStorage.getItem(`tilda_members_profile${project_id}`) ||
      localStorage.getItem("memberarea_profile") ||
      "{}"
  );
  profile["login"] = encodeURIComponent(profile["login"]);
  ["groups", "courses"].forEach((key) => delete profile[key]);
  const filters = new URLSearchParams(window.location.search).get(
    `filters${block_id}`
  );
  $.post(
    TOOLS_RUNNER_URL,
    JSON.stringify({
      tool_id: tool_id,
      profile: profile,
      project_id: project_id,
      referer: document.location.origin,
      user_agent: navigator.userAgent,
      filters: filters,
    }),
    function (data) {
      if ("error" in data) {
        container.text(`Collabza error (${BLOCK_ID}): ${data.error}`);
        container.css("text-align", "center");
        return;
      }
      $.getScript(SHOWDOWN_URL, function () {
        const converter = new showdown.Converter();
        function setConverted(element, value) {
          element.html(converter.makeHtml(String(value)));
          element.css("white-space", "pre-wrap");
          element.find("blockquote").css({
            "white-space": "normal",
            "border-left": "3px solid #333333",
            "padding-left": "20px",
          });
          element.find("img").css("width", "100%");
        }

        data.records.forEach(function (record, index) {
          item = block.clone().attr("id", `rec${block_id}_${index}`);
          item
            .find(".js-product")
            .attr("data-product-url", record.product_url || "");
          if ("title" in record) {
            setConverted(item.find(".t744__title"), record.title);
          }
          if ("subtitle_prod" in record) {
            item.find(".js-product-sku").text(record.subtitle_prod);
          }
          if ("price" in record) {
            if (record.price) {
              item.find(".t744__price .t744__price-value").text(record.price);
            } else {
              item.find(".t744__price-wrapper").remove();
            }
          }
          if ("price_old" in record) {
            if (record.price_old) {
              item
                .find(".t744__price_old .t744__price-value")
                .text(record.price_old);
            } else {
              item.find(".t744__price_old").remove();
            }
          }
          if ("description" in record) {
            setConverted(item.find(".t744__descr"), record.description);
          }
          const button = item.find(".t744__btn");
          if ("button_text" in record) {
            if (record.button_text) {
              button.find("td").text(record.button_text);
            } else {
              button.remove();
            }
          }
          if ("button_link" in record) {
            if (record.button_link) {
              button.attr("href", record.button_link);
            } else {
              button.remove();
            }
          }
          if ("image_list" in record) {
            const image_list = record.image_list;
            const slider = item.find(".t-slds__items-wrapper");
            slider.attr("data-slider-totalslides", image_list.length);
            slider.removeAttr("data-slider-initialized");

            const slides = item.find(".t-slds__item");
            const thumbs = item.find(
              ".t-slds__thumbsbullet-wrapper .t-slds__thumbsbullet"
            );
            const bullets = item.find(
              ".t-slds__bullet_wrapper .t-slds__bullet"
            );
            if (image_list.length > 0) {
              let last_slide = slides
                .first()
                .removeClass("t-slds__item_active");
              let last_thumb = thumbs
                .first()
                .removeClass("t-slds__bullet_active");
              let last_bullet = bullets
                .first()
                .removeClass("t-slds__bullet_active");
              record.image_list.forEach((image, index) => {
                last_slide = insertSlideAfter(
                  last_slide,
                  image_list.length,
                  index + 1,
                  image
                );
                last_thumb = insertThumbAfter(last_thumb, index + 1, image);
                last_bullet = insertBulletAfter(last_bullet, index + 1);
              });
              if (image_list.length === 1) {
                item.find(".t-slds__arrow").remove();
                item.find(".t-slds__thumbsbullet-wrapper").remove();
                item.find(".t-slds__bullet_wrapper").remove();
              }
            } else {
              item.find(".t-slds").remove();
            }
            slides.remove();
            thumbs.remove();
            bullets.remove();
            item
              .find(".t-slds__thumbsbullet-wrapper .t-slds__thumbsbullet")
              .first()
              .addClass("t-slds__bullet_active");
            item
              .find(".t-slds__bullet_wrapper .t-slds__bullet")
              .first()
              .addClass("t-slds__bullet_active");
          }
          for (let i = 3; i >= 1; i--) {
            if (`option${i}_variants` in record) {
              if (record[`option${i}_variants`].length) {
                const variants = item
                  .find(".t-product__option-select")
                  .eq(i - 1)
                  .empty();
                for (const variant of record[`option${i}_variants`]) {
                  const params = variant.split("=");
                  variants.append(
                    `<option value="${params[0]}" data-product-variant-price="${
                      params[1] || ""
                    }">${params[0]}</option>`
                  );
                }
                variants.val(variants.find("option:first").val());
              } else {
                item
                  .find(".t-product__option")
                  .eq(i - 1)
                  .remove();
              }
            }
          }

          item.appendTo(container);
          t744_init(`${block_id}_${index}`);
        });

        if (typeof tcart__addEvent__links === "function") {
          tcart__addEvent__links();
        }

        $(".t-zoomer__wrapper").remove();
        if (typeof t_initZoom === "function") {
          t_initZoom();
        }
        try {
          twishlist__addProductButtons();
        } catch (e) {}
        container.trigger("collabza_loaded");
      });
    }
  ).fail(function (data) {
    container.text(
      `Collabza error (${BLOCK_ID}): ${data?.responseJSON?.message}`
    );
    container.css("text-align", "center");
  });
});
}
